function [AM,x,y]=InterpTriangle(xa,ya,xb,yb,xc,yc,normx,normy)
%This function computes the coordinates of point M such that:
%- M is on the segment [BC]
%- M in on the line (D) that goes through point A and whose
%direction-vector is colinear to V=(normx,normy)
%- A, B, C, M have (xa,ya), (xb,yb), (xc,yc), (x,y) as coordinates
%- AM is the distance between A and M
%
%use: [AM,x,y]=InterpTriangle(xa,ya,xb,yb,xc,yc,normx,normy)
%
%All inputs and outputs are compulsory
%
%(c) Aymeric-Pierre B. Peyret 2010-2011


%
% AC=sqrt((xc-xa)^2+(yc-ya)^2);
% AB=sqrt((xb-xa)^2+(yb-ya)^2);
%
% sina=sqrt(1-cosa^2);
% sinb=sqrt(1-cosb^2);
%
% % x=(AC*cosb*xa*xb^2+AC*cosb*yc*ya*xb-xb*AC*cosb*xa^2+xb*AB*cosa*xa^2+AB*cosa*yc^2*xb-AB*cosa*xa*xc*xb-AC*cosb*xa*xc*xb-2*AB*cosa*yc*ya*xb-xb*AC*cosb*ya^2+xb*AB*cosa*ya^2-AC*cosb*yc*xb*yb+AC*cosb*yb*xb*ya+xc*AB*cosa*yc*ya+AC*cosb*yb^2*xc-2*AC*cosb*yb*ya*xc+AC*cosb*xa^2*xc+AC*cosb*ya^2*xc-AB*cosa*yc*yb*xc+AB*cosa*yb*ya*xc-AB*cosa*xa^2*xc-AB*cosa*ya^2*xc+AB*cosa*xa*xc^2)/(AC*cosb*xb^2-xb*AC*cosb*xc-xb*AC*cosb*xa-xb*AB*cosa*xc+xb*AB*cosa*xa+AC*cosb*xa*xc-AC*cosb*yc*yb-AC*cosb*yb*ya-AB*cosa*yc*yb+AC*cosb*yb^2-AB*cosa*yc*ya+AC*cosb*yc*ya-AB*cosa*xa*xc+AB*cosa*yb*ya+AB*cosa*xc^2+AB*cosa*yc^2);
% % y=(yc-yb)/(xc-xb)*(x-xb)+yb;
% x=xb+(xc-xb)/(1+(AC*sina)/(AB*sinb));
% y=yb+(yc-yb)/(1+(AC*sina)/(AB*sinb));
% AM=sqrt((x-xa)^2+(y-ya)^2);


if normx~=0%vector V is not vertical
    kp=((xa*normy-ya*normx)-(xc*normy-yc*normx))/(normy*(xb-xc)-normx*(yb-yc));
    k=(kp*(xb-xc)+(xc-xa))/normx;
    
    x=xa+k*normx;
    y=ya+k*normy;
    AM=abs(k);
else%when vector V is vertical
    x=xa;
    y=yb+(x-xb)*(yc-yb)/(xc-xb);
    AM=abs(y-ya);
end